class SubredditDownloaderConfig:
    DEFAULT_CATEGORIES = ["hot", "new", "random_rising", "rising",
                          "controversial", "top", "gilded"]
    DEFAULT_POST_LIMIT = None